ChangeLog
=========

v1.1.4 (2018-08-17)
-------------------

* Fix an issue in setting matplotlib backend

v1.1.3 (2018-01-19)
-------------------

* Fix a bug in the file name of filtered biased peaks

* Fix a typo

v1.1.2 (2018-01-18)
-------------------

* Keep five digits for floats in the output files

* Fix a typo


v1.1.1 (2018-01-11)
-------------------

* Add test module

Bugs fixed:

* Rename the file name of filtered biased peaks



v1.1 (2017-11-07)
-----------------

Improvements:

* Refactor the package for better performance and compatibility

Bugs fixed:

* Fix the coordinates of peaks to be consistent with the corresponding coordinate system
* Fix the approximate equation in p-value calculation
* Fix the summit calculation of merged common peaks
